aboutsummaryrefslogtreecommitdiffstats
path: root/tests/unit/dialog/core.js
diff options
context:
space:
mode:
Diffstat (limited to 'tests/unit/dialog/core.js')
-rw-r--r--tests/unit/dialog/core.js7
1 files changed, 4 insertions, 3 deletions
diff --git a/tests/unit/dialog/core.js b/tests/unit/dialog/core.js
index 9e89eaa0f..169734f1c 100644
--- a/tests/unit/dialog/core.js
+++ b/tests/unit/dialog/core.js
@@ -1,11 +1,12 @@
define( [
"qunit",
"jquery",
+ "lib/helper",
"ui/widgets/dialog"
-], function( QUnit, $ ) {
+], function( QUnit, $, helper ) {
-// TODO add teardown callback to remove dialogs
-QUnit.module( "dialog: core" );
+// TODO add afterEach callback to remove dialogs
+QUnit.module( "dialog: core", { afterEach: helper.moduleAfterEach } );
QUnit.test( "markup structure", function( assert ) {
assert.expect( 11 );